@@ -9,23 +9,10 @@ import sentry
 
 from django.utils.translation import ugettext_lazy as _
 
-from sentry.filters import Filter
-from sentry.models import Event
 from sentry.plugins import register
 from sentry.plugins.bases.tag import TagPlugin
 
 
-class SiteFilter(Filter):
-    label = _('Site')
-    column = 'site'
-
-    def get_query_set(self, queryset):
-        if queryset.model == Event:
-            return queryset.filter(site=self.get_value()).distinct()
-        else:
-            return queryset.filter(event_set__site=self.get_value()).distinct()
-
-
 class SitesPlugin(TagPlugin):
     """
     Adds additional support for showing information about sites including:
@@ -46,7 +33,4 @@ class SitesPlugin(TagPlugin):
             return []
         return [event.site]
 
-    def get_filters(self, project=None, **kwargs):
-        return [SiteFilter]
-
 register(SitesPlugin)
