@@ -56,24 +56,6 @@ class RemoveProjectForm(forms.Form):
         return password
 
 
-class NewProjectForm(forms.ModelForm):
-    name = forms.CharField(max_length=200, widget=forms.TextInput(attrs={'placeholder': _('e.g. My Project Name')}))
-    slug = forms.SlugField(help_text=_('A slug is a URL-safe word and must be unique across all projects.'),
-        widget=forms.TextInput(attrs={'placeholder': _('e.g. my-project-name')}))
-
-    class Meta:
-        fields = ('name', 'slug')
-        model = Project
-
-
-class NewProjectAdminForm(NewProjectForm):
-    owner = UserField(required=False)
-
-    class Meta:
-        fields = ('name', 'slug', 'owner')
-        model = Project
-
-
 class EditProjectForm(forms.ModelForm):
     public = forms.BooleanField(required=False, help_text=_('Allow anyone (even anonymous users) to view this project'))
     team = forms.ChoiceField(choices=())
@@ -94,10 +76,13 @@ class EditProjectForm(forms.ModelForm):
         if len(team_list) == 1 and instance.team == team_list.values()[0]:
             del self.fields['team']
         else:
-            self.fields['team'].choices = [(t.pk, t) for t in sorted(self.team_list.values(), key=lambda x: x.name)]
+            team_choices = [(t.pk, t) for t in sorted(self.team_list.values(), key=lambda x: x.name)]
             if not instance.team:
-                self.fields['team'].choices.insert(0, (None, '-' * 8))
-            self.fields['team'].widget.choices = self.fields['team'].choices
+                team_choices.insert(0, ('', '-' * 8))
+            elif (instance.team.pk, instance.team) not in team_choices:
+                team_choices.insert(1, (instance.team.pk, instance.team))
+            self.fields['team'].choices = team_choices
+            self.fields['team'].widget.choices = team_choices
 
     def clean_team(self):
         value = self.cleaned_data.get('team')
@@ -117,6 +102,7 @@ class EditProjectForm(forms.ModelForm):
 
 
 class EditProjectAdminForm(EditProjectForm):
+    team = forms.ChoiceField(choices=(), required=False)
     owner = UserField(required=False)
 
     class Meta:
